@@ -6,7 +6,6 @@
 #ifdef OS_WINDOWS
    #include <winsock2.h>
    #include <ws2tcpip.h>
-   #include <missing/inet_aton.h>
 #else
    #include <netinet/in.h>
    #include <arpa/inet.h>
@@ -54,6 +53,7 @@
 #define IP6_SOL_NODE "\xff\x02\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\xff\x00\x00\x00"
 
 #define IP6_DSTOPT_UNKN "\x80\x01\x00\x00\x00"
+#define LLA_IP6_ALLNODES_MULTICAST "\x33\x33\x00\x00\x00\x01"
 
 /* 
  * this structure is used by ettercap to handle 
@@ -84,7 +84,7 @@ EC_API_EXTERN int ip_addr_cmp(struct ip_addr *sa, struct ip_addr *sb);
 EC_API_EXTERN int ip_addr_null(struct ip_addr *sa);
 EC_API_EXTERN int ip_addr_is_zero(struct ip_addr *sa);
 EC_API_EXTERN int ip_addr_random(struct ip_addr* ip, u_int16 type);
-EC_API_EXTERN int ip_addr_init_sol(struct ip_addr* sn, struct ip_addr* ip);
+EC_API_EXTERN int ip_addr_init_sol(struct ip_addr* sn, struct ip_addr* ip, u_int8 *tmac);
 
 EC_API_EXTERN char *ip_addr_ntoa(struct ip_addr *sa, char *dst);
 EC_API_EXTERN int ip_addr_pton(char *str, struct ip_addr *addr);
