@@ -1,8 +1,5 @@
-
-
-#ifndef EC_POLL_H
-#define EC_POLL_H
-
+#ifndef ETTERCAP_POLL_H
+#define ETTERCAP_POLL_H
 
 EC_API_EXTERN int ec_poll_in(int fd, u_int msec);
 EC_API_EXTERN int ec_poll_out(int fd, u_int msec);
