@@ -43,6 +43,9 @@ EC_API_EXTERN int host_iptoa(struct ip_addr *ip, char *name);
 
 /* used by ec_dns to insert passively sniffed dns answers */
 EC_API_EXTERN void resolv_cache_insert_passive(struct ip_addr *ip, char *name);
+/* initialize and teardown name resolver threads */
+EC_API_EXTERN void resolv_thread_init(void);
+EC_API_EXTERN void resolv_thread_fini(void);
    
 
    
