@@ -1,5 +1,5 @@
 /*
-    ettercap -- dissector irc -- TCP 6666 6667 6668 6669
+    ettercap -- dissector irc -- TCP 6665 6666 6667 6668 6669
 
     Copyright (C) ALoR & NaGA
 
@@ -39,6 +39,7 @@ void irc_init(void);
 
 void __init irc_init(void)
 {
+   dissect_add("irc", APP_LAYER_TCP, 6665, dissector_irc);
    dissect_add("irc", APP_LAYER_TCP, 6666, dissector_irc);
    dissect_add("irc", APP_LAYER_TCP, 6667, dissector_irc);
    dissect_add("irc", APP_LAYER_TCP, 6668, dissector_irc);
@@ -55,6 +56,9 @@ FUNC_DECODER(dissector_irc)
 
    /* unused variable */
    (void)end;
+   (void) DECODE_DATA; 
+   (void) DECODE_DATALEN;
+   (void) DECODED_LEN;
 
    /* skip messages coming from the server */
    if (FROM_SERVER("irc", PACKET) || FROM_SERVER("ircs", PACKET))
@@ -81,7 +85,7 @@ FUNC_DECODER(dissector_irc)
       dissect_create_ident(&ident, PACKET, DISSECT_CODE(dissector_irc));
       
       /* get the saved nick */
-      if (session_get(&s, ident, DISSECT_IDENT_LEN) == ESUCCESS)
+      if (session_get(&s, ident, DISSECT_IDENT_LEN) == E_SUCCESS)
          PACKET->DISSECTOR.user = strdup(s->data);
       else
          PACKET->DISSECTOR.user = strdup("unknown");
@@ -201,7 +205,7 @@ FUNC_DECODER(dissector_irc)
       dissect_create_ident(&ident, PACKET, DISSECT_CODE(dissector_irc));
       
       /* get the saved nick */
-      if (session_get(&s, ident, DISSECT_IDENT_LEN) == ESUCCESS)
+      if (session_get(&s, ident, DISSECT_IDENT_LEN) == E_SUCCESS)
          PACKET->DISSECTOR.user = strdup(s->data);
       else
          PACKET->DISSECTOR.user = strdup("unknown");
@@ -244,7 +248,7 @@ FUNC_DECODER(dissector_irc)
       dissect_create_ident(&ident, PACKET, DISSECT_CODE(dissector_irc));
       
       /* get the saved nick */
-      if (session_get(&s, ident, DISSECT_IDENT_LEN) == ESUCCESS)
+      if (session_get(&s, ident, DISSECT_IDENT_LEN) == E_SUCCESS)
          PACKET->DISSECTOR.user = strdup(s->data);
       else
          PACKET->DISSECTOR.user = strdup("unknown");
@@ -290,7 +294,7 @@ FUNC_DECODER(dissector_irc)
       dissect_create_ident(&ident, PACKET, DISSECT_CODE(dissector_irc));
       
       /* get the saved nick */
-      if (session_get(&s, ident, DISSECT_IDENT_LEN) == ESUCCESS)
+      if (session_get(&s, ident, DISSECT_IDENT_LEN) == E_SUCCESS)
          PACKET->DISSECTOR.user = strdup(s->data);
       else
          PACKET->DISSECTOR.user = strdup("unknown");
