@@ -1,5 +1,5 @@
 /*
-    ettercap -- dissector mountd - RPC
+    ettercap -- dissector mountd -- TCP 2049
 
     Copyright (C) ALoR & NaGA
 
@@ -45,6 +45,7 @@ void mountd_init(void);
 void __init mountd_init(void)
 {
    /* This is inserted into the dissectors' chain by the portmap dissector */
+   dissect_add("mountd", APP_LAYER_TCP, 2049, dissector_mountd);
 }
 
 FUNC_DECODER(dissector_mountd)
@@ -52,13 +53,15 @@ FUNC_DECODER(dissector_mountd)
    DECLARE_DISP_PTR_END(ptr, end);
    u_int32 type, xid, proc, program, version, flen, cred, offs, i;
    mountd_session *pe;
-   char *fhandle;
    struct ec_session *s = NULL;
    void *ident = NULL;
    char tmp[MAX_ASCII_ADDR_LEN];
 
    /* don't complain about unused var */
    (void)end;
+   (void) DECODE_DATA; 
+   (void) DECODE_DATALEN;
+   (void) DECODED_LEN;
 
    /* skip packets which are not useful */
    if (PACKET->DATA.len < 24)
@@ -105,7 +108,7 @@ FUNC_DECODER(dissector_mountd)
 
    /* REPLY */
    dissect_create_ident(&ident, PACKET, DISSECT_CODE(dissector_mountd));
-   if (session_get(&s, ident, DISSECT_IDENT_LEN) == -ENOTFOUND) {
+   if (session_get(&s, ident, DISSECT_IDENT_LEN) == -E_NOTFOUND) {
       SAFE_FREE(ident);
       return NULL;
    }
@@ -130,16 +133,18 @@ FUNC_DECODER(dissector_mountd)
       offs = 28;
    }
 
-   SAFE_CALLOC(fhandle, (flen*3) + 10, 1);
-   for (i=0; i<flen; i++)
-      snprintf(fhandle, (flen*3) + 10, "%s%.2x ", fhandle, ptr[i + offs]);
+   DISSECT_MSG("mountd : Server:%s Handle %s: [ ",
+         ip_addr_ntoa(&PACKET->L3.src, tmp), pe->rem_dir);
+
+   for (i=0; i<flen; i++) {
+      if ((i*3)+1 > (flen*3)+10)
+         break;
+      DISSECT_MSG("%02x ", ptr[i + offs]);
+   }
    
-   DISSECT_MSG("mountd : Server:%s Handle %s: [%s]\n", ip_addr_ntoa(&PACKET->L3.src, tmp),
-                                                       pe->rem_dir, 
-                                                       fhandle);
+   DISSECT_MSG("]\n");
 
    SAFE_FREE(pe->rem_dir);
-   SAFE_FREE(fhandle);
    dissect_wipe_session(PACKET, DISSECT_CODE(dissector_mountd));
    return NULL;
 }
