@@ -57,6 +57,11 @@ FUNC_DECODER(dissector_nntp)
    void *ident = NULL;
    char tmp[MAX_ASCII_ADDR_LEN];
    
+   /* don't complain about unused var */
+   (void) DECODE_DATA; 
+   (void) DECODE_DATALEN;
+   (void) DECODED_LEN;
+   
    /* the connection is starting... create the session */
    CREATE_SESSION_ON_SYN_ACK("nntp", s, dissector_nntp);
    CREATE_SESSION_ON_SYN_ACK("nntps", s, dissector_nntp);
@@ -133,7 +138,7 @@ FUNC_DECODER(dissector_nntp)
       dissect_create_ident(&ident, PACKET, DISSECT_CODE(dissector_nntp));
       
       /* retrieve the session and delete it */
-      if (session_get_and_del(&s, ident, DISSECT_IDENT_LEN) == -ENOTFOUND) {
+      if (session_get_and_del(&s, ident, DISSECT_IDENT_LEN) == -E_NOTFOUND) {
          SAFE_FREE(ident);
          return NULL;
       }
