@@ -26,50 +26,70 @@
 /* protos... */
 
 static u_int16 sum(u_int8 *buf, size_t len);
-u_int16 L3_checksum(u_char *buf, size_t len);
-u_int16 L4_checksum(struct packet_object *po);
 static u_int16 v4_checksum(struct packet_object *po);
 static u_int16 v6_checksum(struct packet_object *po);
-u_int16 checksum_shouldbe(u_int16 sum, u_int16 computed_sum);
-u_int32 CRC_checksum(u_char *buf, size_t len, u_int32 init);
 
 /*******************************************/
 
 
 static u_int16 sum(u_int8 *buf, size_t len)
 {
+   /* create union for type punning - elements named as their rep. type */
+   union {
+      u_int8  u_int8 [4];
+      u_int16 u_int16[2];
+      u_int32 u_int32;
+   } u;
+   register u_int8 *cbuf = buf;
 #if OS_SIZEOF_P == 8
    register u_int64 csum = 0;
-   register u_int32 *cbuf = (u_int32 *)buf;
 #elif OS_SIZEOF_P == 4
    register u_int32 csum = 0;
-   register u_int16 *cbuf = (u_int16 *)buf;
 #endif
    register unsigned int nleft = len;
-   u_int16 tmp = 0;
 
-   while(nleft > sizeof(*cbuf) - 1) {
-      csum += *cbuf++;
-      nleft -= sizeof(*cbuf);
-   }
+
 #if OS_SIZEOF_P == 8
-   while(nleft > 1) {
-      csum += *(u_int16*)cbuf++;
+   while(nleft >= sizeof(u_int32)) {
+      /* assigning bytes from buffer to union for 64-bit systems */
+      u.u_int8[0] = cbuf[0];
+      u.u_int8[1] = cbuf[1];
+      u.u_int8[2] = cbuf[2];
+      u.u_int8[3] = cbuf[3];
+
+      csum += u.u_int32;
+      cbuf += sizeof(u_int32);
+      nleft -= sizeof(u_int32);
+   }
+#endif
+
+   while(nleft >= sizeof(u_int16)) {
+      /* assigning bytes from buffer to union for 32-bit systems */
+      u.u_int8[0] = cbuf[0];
+      u.u_int8[1] = cbuf[1];
+
+      csum += u.u_int16[0];
+      cbuf += sizeof(u_int16);
       nleft -= sizeof(u_int16);
    }
-#endif
+
    if(nleft) {
-      *(u_int8*)&tmp = *(u_int8*)cbuf;
-      csum += tmp;
+      /* one word left */
+      u.u_int8[0] = cbuf[0];
+      u.u_int8[1] = 0;
+
+      csum += u.u_int16[0];
+      cbuf++;
+      nleft--;
    }
 
 #if OS_SIZEOF_P == 8
-   while(csum >> 32)
-      csum = (csum >> 32) + (csum & 0xffffffff);
+   csum = (csum >> 32) + (csum & 0xffffffff);
+   csum = (csum >> 32) + (csum & 0xffffffff);
 #endif
 
-   while(csum >> 16)
-      csum = (csum >> 16) + (csum & 0xffff);
+   csum = (csum >> 16) + (csum & 0xffff);
+   csum += (csum >> 16);
 
    return csum;
 }
@@ -109,16 +129,16 @@ static u_int16 v4_checksum(struct packet_object *po)
    csum = sum(po->L4.header, len);
 
    /* check the pseudo header */
-   csum += ip_addr_to_int32(&po->L3.src.addr) & 0xffff;
-   csum += ip_addr_to_int32(&po->L3.src.addr) >> 16;
-   csum += ip_addr_to_int32(&po->L3.dst.addr) & 0xffff;
-   csum += ip_addr_to_int32(&po->L3.dst.addr) >> 16;
+   csum += po->L3.src.addr16[0];
+   csum += po->L3.src.addr16[1];
+   csum += po->L3.dst.addr16[0];
+   csum += po->L3.dst.addr16[1];
 
    csum += htons((u_int16)po->L4.proto);
    csum += htons(len);
 
-   while(csum >> 16)
-      csum = (csum >> 16) + (csum & 0xffff);
+   csum = (csum >> 16) + (csum & 0xffff);
+   csum += (csum >> 16);
    
    return (u_int16)(~csum);
 }
@@ -135,8 +155,8 @@ static u_int16 v6_checksum(struct packet_object *po)
    csum += sum((uint8_t*)&po->L3.dst.addr, ntohs(po->L3.dst.addr_len));
    csum += htons(plen + po->L4.proto);
 
-   while(csum >> 16)
-      csum = (csum & 0xffff) + (csum >> 16);
+   csum = (csum & 0xffff) + (csum >> 16);
+   csum += (csum >> 16);
 
    return (u_int16)(~csum);
 }
