@@ -37,9 +37,9 @@ char * get_full_path(const char *dir, const char *file)
    SAFE_CALLOC(filename, len, sizeof(char));
    
    if (!strcmp(dir, "etc"))
-      snprintf(filename, len, "%s/%s/%s", INSTALL_SYSCONFDIR, EC_PROGRAM, file);
+      snprintf(filename, len, "%s/%s/%s", INSTALL_SYSCONFDIR, PROGRAM, file);
    else if (!strcmp(dir, "share"))
-      snprintf(filename, len, "%s/%s/%s", INSTALL_DATADIR, EC_PROGRAM, file);
+      snprintf(filename, len, "%s/%s/%s", INSTALL_DATADIR, PROGRAM, file);
 
    DEBUG_MSG("get_full_path -- [%s] %s", dir, filename);
    
