@@ -156,15 +156,18 @@ int ip_addr_random(struct ip_addr* ip, u_int16 type)
 }
 
 /*
- * initialize a solicited-node address from a given ip address.
- * returns E_SUCCESS on success or -E_INVALID in case of a 
- * unsupported address familily (actually only IPv6 is supported)
+ * initialize a solicited-node IPv6 and link-layer address from a
+ * given ip address.
+ *
+ * returns E_SUCCESS on success or -E_INVALID in case of a unsupported
+ * address familily (actually only IPv6 is supported)
  */
-int ip_addr_init_sol(struct ip_addr* sn, struct ip_addr* ip)
+int ip_addr_init_sol(struct ip_addr* sn, struct ip_addr* ip, u_int8 *tmac)
 {
    switch (ntohs(ip->addr_type)) {
       case AF_INET:
          (void) sn;
+         (void) tmac;
          /* not applicable for IPv4 */
       break;
 #ifdef WITH_IPV6
@@ -177,6 +180,15 @@ int ip_addr_init_sol(struct ip_addr* sn, struct ip_addr* ip)
          ip_addr_init(sn, AF_INET6, (u_char*)IP6_SOL_NODE);
          memcpy((sn->addr + 13), (ip->addr + 13), 3);
 
+         /*
+          * initialize the MAC address derived from the solicited
+          * node multicast IPv6 address by overwriting the tailing
+          * 32-bit of the all-nodes link-layer multicast address for IPv6
+          */
+         memcpy(tmac, LLA_IP6_ALLNODES_MULTICAST, MEDIA_ADDR_LEN);
+         memcpy((tmac + 2), (sn->addr + 12), 4);
+
+
          return E_SUCCESS;
       break;
 #endif
@@ -212,7 +224,7 @@ inet_ntop4(const u_char *src, char *dst, size_t size)
    char str[IP_ASCII_ADDR_LEN];
    int n;
    
-	n = snprintf(str, IP_ASCII_ADDR_LEN, "%u.%u.%u.%u", src[0], src[1], src[2], src[3]);
+   n = snprintf(str, IP_ASCII_ADDR_LEN, "%u.%u.%u.%u", src[0], src[1], src[2], src[3]);
    
    str[n] = '\0';
  
@@ -224,90 +236,90 @@ inet_ntop4(const u_char *src, char *dst, size_t size)
 const char *
 inet_ntop6(const u_char *src, char *dst, size_t size)
 {
-	/*
-	 * Note that int32_t and int16_t need only be "at least" large enough
-	 * to contain a value of the specified size.  On some systems, like
-	 * Crays, there is no such thing as an integer variable with 16 bits.
-	 * Keep this in mind if you think this function should have been coded
-	 * to use pointer overlays.  All the world's not a VAX.
-	 */
-	char tmp[IP6_ASCII_ADDR_LEN], *tp;
-	struct { int base, len; } best, cur;
-	u_int words[NS_IN6ADDRSZ / NS_INT16SZ];
-	int i;
+   /*
+    * Note that int32_t and int16_t need only be "at least" large enough
+    * to contain a value of the specified size.  On some systems, like
+    * Crays, there is no such thing as an integer variable with 16 bits.
+    * Keep this in mind if you think this function should have been coded
+    * to use pointer overlays.  All the world's not a VAX.
+    */
+   char tmp[IP6_ASCII_ADDR_LEN], *tp;
+   struct { int base, len; } best, cur;
+   u_int words[NS_IN6ADDRSZ / NS_INT16SZ];
+   int i;
 
-	best.len = 0;
-	cur.len = 0;
+   best.len = 0;
+   cur.len = 0;
 
-	/*
-	 * Preprocess:
-	 *	Copy the input (bytewise) array into a wordwise array.
-	 *	Find the longest run of 0x00's in src[] for :: shorthanding.
-	 */
-	memset(words, '\0', sizeof words);
-	for (i = 0; i < NS_IN6ADDRSZ; i += 2)
-		words[i / 2] = (src[i] << 8) | src[i + 1];
-	best.base = -1;
-	cur.base = -1;
-	for (i = 0; i < (NS_IN6ADDRSZ / NS_INT16SZ); i++) {
-		if (words[i] == 0) {
-			if (cur.base == -1)
-				cur.base = i, cur.len = 1;
-			else
-				cur.len++;
-		} else {
-			if (cur.base != -1) {
-				if (best.base == -1 || cur.len > best.len)
-					best = cur;
-				cur.base = -1;
-			}
-		}
-	}
-	if (cur.base != -1) {
-		if (best.base == -1 || cur.len > best.len)
-			best = cur;
-	}
-	if (best.base != -1 && best.len < 2)
-		best.base = -1;
+   /*
+    * Preprocess:
+    *   Copy the input (bytewise) array into a wordwise array.
+    *   Find the longest run of 0x00's in src[] for :: shorthanding.
+    */
+   memset(words, '\0', sizeof words);
+   for (i = 0; i < NS_IN6ADDRSZ; i += 2)
+      words[i / 2] = (src[i] << 8) | src[i + 1];
+   best.base = -1;
+   cur.base = -1;
+   for (i = 0; i < (NS_IN6ADDRSZ / NS_INT16SZ); i++) {
+      if (words[i] == 0) {
+         if (cur.base == -1)
+            cur.base = i, cur.len = 1;
+         else
+            cur.len++;
+      } else {
+         if (cur.base != -1) {
+            if (best.base == -1 || cur.len > best.len)
+               best = cur;
+            cur.base = -1;
+         }
+      }
+   }
+   if (cur.base != -1) {
+      if (best.base == -1 || cur.len > best.len)
+         best = cur;
+   }
+   if (best.base != -1 && best.len < 2)
+      best.base = -1;
 
-	/*
-	 * Format the result.
-	 */
-	tp = tmp;
-	for (i = 0; i < (NS_IN6ADDRSZ / NS_INT16SZ); i++) {
-		/* Are we inside the best run of 0x00's? */
-		if (best.base != -1 && i >= best.base &&
-		    i < (best.base + best.len)) {
-			if (i == best.base)
-				*tp++ = ':';
-			continue;
-		}
-		/* Are we following an initial run of 0x00s or any real hex? */
-		if (i != 0)
-			*tp++ = ':';
-		/* Is this address an encapsulated IPv4? */
-		if (i == 6 && best.base == 0 &&
-		    (best.len == 6 || (best.len == 5 && words[5] == 0xffff))) {
-			if (inet_ntop4(src+12, tp, IP_ASCII_ADDR_LEN) != 0)
-				return (NULL);
-			tp += strlen(tp);
-			break;
-		}
-		tp += sprintf(tp, "%x", words[i]);
-	}
-	/* Was it a trailing run of 0x00's? */
-	if (best.base != -1 && (best.base + best.len) == 
-	    (NS_IN6ADDRSZ / NS_INT16SZ))
-		*tp++ = ':';
-	*tp++ = '\0';
+   /*
+    * Format the result.
+    */
+   tp = tmp;
+   for (i = 0; i < (NS_IN6ADDRSZ / NS_INT16SZ); i++) {
+      /* Are we inside the best run of 0x00's? */
+      if (best.base != -1 && i >= best.base &&
+          i < (best.base + best.len)) {
+         if (i == best.base)
+            *tp++ = ':';
+         continue;
+      }
+      /* Are we following an initial run of 0x00s or any real hex? */
+      if (i != 0)
+         *tp++ = ':';
+      /* Is this address an encapsulated IPv4? */
+      if (i == 6 && best.base == 0 &&
+          (best.len == 6 || (best.len == 5 && words[5] == 0xffff))) {
+         if (inet_ntop4(src+12, tp, IP_ASCII_ADDR_LEN) != 0)
+            return (NULL);
+         tp += strlen(tp);
+         break;
+      }
+      tp += sprintf(tp, "%x", words[i]);
+   }
+   /* Was it a trailing run of 0x00's? */
+   if (best.base != -1 && (best.base + best.len) == 
+       (NS_IN6ADDRSZ / NS_INT16SZ))
+      *tp++ = ':';
+   *tp++ = '\0';
 
-  	/*
-	 * Check for overflow, copy, and we're done.
-	 */
-	if ((size_t)(tp - tmp) > size) {
-		__set_errno (ENOSPC);
-		return (NULL);
-	}
+     /*
+    * Check for overflow, copy, and we're done.
+    */
+   if ((size_t)(tp - tmp) > size) {
+      __set_errno (ENOSPC);
+      return (NULL);
+   }
 
    strncpy(dst, tmp, size);
    
@@ -317,15 +329,22 @@ inet_ntop6(const u_char *src, char *dst, size_t size)
 /* Converts character string to IP address if possible */
 int ip_addr_pton(char *str, struct ip_addr *addr)
 {
-   u_int8 buf[MAX_IP_ADDR_LEN];
-   int proto;
-
-   proto = (strchr(str, ':')) ? AF_INET6 : AF_INET;
+   struct in_addr inaddr;
+#ifdef WITH_IPV6
+   struct in6_addr in6addr;
+#endif
    
-   if(inet_pton(proto, str, buf) == 1) {
-      ip_addr_init(addr, proto, buf);
+   if(inet_pton(AF_INET, str, &inaddr) == 1) { /* try IPv4 */
+      ip_addr_init(addr, AF_INET, (u_char*)&inaddr);
       return E_SUCCESS;
-   } else {
+   }
+#ifdef WITH_IPV6
+   else if (inet_pton(AF_INET6, str, &in6addr) == 1) { /* try IPv6 */
+      ip_addr_init(addr, AF_INET6, (u_char*)&in6addr);
+      return E_SUCCESS;
+   } 
+#endif
+   else {
       return -E_INVALID;
    }
 }
@@ -338,7 +357,7 @@ char *mac_addr_ntoa(u_char *mac, char *dst)
    char str[ETH_ASCII_ADDR_LEN];
    int n;
    
-	n = snprintf(str, ETH_ASCII_ADDR_LEN, "%02X:%02X:%02X:%02X:%02X:%02X", 
+   n = snprintf(str, ETH_ASCII_ADDR_LEN, "%02X:%02X:%02X:%02X:%02X:%02X", 
          mac[0], mac[1], mac[2], mac[3], mac[4], mac[5]);
    
    str[n] = '\0';
@@ -383,7 +402,16 @@ int ip_addr_is_global(struct ip_addr *ip)
 
    switch (ntohs(ip->addr_type)) {
       case AF_INET:
-         /* XXX one could implement here !RFC1918 address determination */
+         /* Global for IPv4 means not status "RESERVED" by IANA */
+         if (
+               *ip->addr != 0x0 &&                         /* not 0/8        */
+               *ip->addr != 0x7f &&                        /* not 127/8      */
+               *ip->addr != 0x0a &&                        /* not 10/8       */
+               (ntohs(*ip->addr16) & 0xfff0) != 0xac10 &&  /* not 172.16/12  */
+               ntohs(*ip->addr16) != 0xc0a8 &&             /* not 192.168/16 */
+               !ip_addr_is_multicast(ip)                   /* not 224/3      */
+            )
+            return 1;
       break;
       case AF_INET6:
          /* 
@@ -427,7 +455,7 @@ int ip_addr_is_multicast(struct ip_addr *ip)
       default:
          return -E_INVALID;
    }
-	return 0;
+   return 0;
 }
 
 /*
@@ -436,36 +464,38 @@ int ip_addr_is_multicast(struct ip_addr *ip)
  */
 int ip_addr_is_broadcast(struct ip_addr *sa)
 {
-	struct ip_addr *nw;
-	struct ip_addr *nm;
+   struct ip_addr *nw;
+   struct ip_addr *nm;
 
-	u_int32* address;
-	u_int32* netmask;
-	u_int32* network;
-	u_int32 broadcast;
+   u_int32* address;
+   u_int32* netmask;
+   u_int32* network;
+   u_int32 broadcast;
 
-	switch(ntohs(sa->addr_type)) {
-		case AF_INET:
-         if(!GBL_IFACE->has_ipv4)
+   switch(ntohs(sa->addr_type)) {
+      case AF_INET:
+         if(!EC_GBL_IFACE->has_ipv4)
             return -E_INVALID;
-			nm = &GBL_IFACE->netmask;
-			nw = &GBL_IFACE->network;
-		
+         nm = &EC_GBL_IFACE->netmask;
+         nw = &EC_GBL_IFACE->network;
+
          /* 255.255.255.255 is definitely broadcast */
          if(!memcmp(sa->addr, "\xff\xff\xff\xff", IP_ADDR_LEN))
             return E_SUCCESS;
 
-			address = sa->addr32;
-			netmask = nm->addr32;
-			network = nw->addr32;
+         address = sa->addr32;
+         netmask = nm->addr32;
+         network = nw->addr32;
 
-			broadcast = (*network) | ~(*netmask);
+         broadcast = (*network) | ~(*netmask);
 
-			if (broadcast == *address)
-				return E_SUCCESS;
-		case AF_INET6:
-			if(!GBL_IFACE->has_ipv6)
-				return -E_INVALID;
+         if (broadcast == *address)
+            return E_SUCCESS;
+
+         break;
+      case AF_INET6:
+         if(!EC_GBL_IFACE->has_ipv6)
+            return -E_INVALID;
 
          /* IPv6 has no such thing as a broadcast address. The closest
           * equivalent is the multicast address ff02::1. Packets sent to that
@@ -474,18 +504,18 @@ int ip_addr_is_broadcast(struct ip_addr *sa)
          if(!memcmp(sa->addr, IP6_ALL_NODES, IP6_ADDR_LEN))
             return E_SUCCESS;
          
-			break;
-	}
+         break;
+   }
 
-	return -E_NOTFOUND;
+   return -E_NOTFOUND;
 }
 
 /*
  * returns E_SUCCESS if the ip address is local.
  * returns -E_NOTFOUND if it is non local.
- * the choice is make reading the GBL_IFACE infos
+ * the choice is make reading the EC_GBL_IFACE infos
  *
- * if the GBL_IFACE is not filled (while reading from files)
+ * if the EC_GBL_IFACE is not filled (while reading from files)
  * returns -E_INVALID.
  */
 int ip_addr_is_local(struct ip_addr *sa, struct ip_addr *ifaddr)
@@ -501,13 +531,13 @@ int ip_addr_is_local(struct ip_addr *sa, struct ip_addr *ifaddr)
 
    switch (ntohs(sa->addr_type)) {
       case AF_INET:
-         nm = &GBL_IFACE->netmask;
-         nw = &GBL_IFACE->network;
+         nm = &EC_GBL_IFACE->netmask;
+         nw = &EC_GBL_IFACE->network;
          /* the address 0.0.0.0 is used by DHCP and it is local for us*/
          if ( !memcmp(&sa->addr, "\x00\x00\x00\x00", ntohs(sa->addr_len)) )
             return E_SUCCESS;
          
-         /* make a check on GBL_IFACE (is it initialized ?) */
+         /* make a check on EC_GBL_IFACE (is it initialized ?) */
          if ( !memcmp(&nw->addr, "\x00\x00\x00\x00", ntohs(sa->addr_len)) )
             /* return UNKNOWN */
             return -E_INVALID;
@@ -518,14 +548,14 @@ int ip_addr_is_local(struct ip_addr *sa, struct ip_addr *ifaddr)
          /* check if it is local */
          if ((*address & *netmask) == *network) {
             if(ifaddr != NULL)
-               memcpy(ifaddr, &GBL_IFACE->ip, sizeof(*ifaddr));
+               memcpy(ifaddr, &EC_GBL_IFACE->ip, sizeof(*ifaddr));
             return E_SUCCESS;
          }
          break;
       case AF_INET6:
-         if(!GBL_IFACE->has_ipv6)
+         if(!EC_GBL_IFACE->has_ipv6)
              return -E_INVALID;
-         LIST_FOREACH(ip6, &GBL_IFACE->ip6_list, next) {
+         LIST_FOREACH(ip6, &EC_GBL_IFACE->ip6_list, next) {
             nm = &ip6->netmask;
             nw = &ip6->network;
             address = sa->addr32;
@@ -564,16 +594,16 @@ int ip_addr_is_ours(struct ip_addr *ip)
    struct net_list *i;
    switch(ntohs(ip->addr_type)) {
       case AF_INET:
-         if(!ip_addr_cmp(ip, &GBL_IFACE->ip))
+         if(!ip_addr_cmp(ip, &EC_GBL_IFACE->ip))
             return E_FOUND;
-         else if(!ip_addr_cmp(ip, &GBL_BRIDGE->ip))
+         else if(!ip_addr_cmp(ip, &EC_GBL_BRIDGE->ip))
             return E_BRIDGE;
          else
             return -E_NOTFOUND;
          break;
 
       case AF_INET6:
-         LIST_FOREACH(i, &GBL_IFACE->ip6_list, next) {
+         LIST_FOREACH(i, &EC_GBL_IFACE->ip6_list, next) {
             if(!ip_addr_cmp(ip, &i->ip))
                return E_FOUND;
          }
