@@ -42,7 +42,7 @@ void unified_set_forwardable(struct packet_object *po);
 void start_unified_sniff(void)
 {
    DEBUG_MSG("start_unified_sniff");
-   if (GBL_SNIFF->active == 1) {
+   if (EC_GBL_SNIFF->active == 1) {
       USER_MSG("Unified sniffing already started...\n");
       return;
    }
@@ -50,7 +50,7 @@ void start_unified_sniff(void)
    USER_MSG("Starting Unified sniffing...\n\n");
    
    /* create the timeouter thread */
-   if (!GBL_OPTIONS->read) { 
+   if (!EC_GBL_OPTIONS->read) { 
       pthread_t pid;
       
       pid = ec_thread_getpid("timer");
@@ -59,16 +59,16 @@ void start_unified_sniff(void)
    }
 
    /* create the thread for packet capture */
-   capture_start(GBL_IFACE);
+   capture_start(EC_GBL_IFACE);
 
-   if(GBL_OPTIONS->secondary)
+   if(EC_GBL_OPTIONS->secondary)
       secondary_sources_foreach(capture_start);
 
    /* start ssl_wrapper thread */
-   if (!GBL_OPTIONS->read && !GBL_OPTIONS->unoffensive && !GBL_OPTIONS->only_mitm && GBL_OPTIONS->ssl_mitm)
+   if (!EC_GBL_OPTIONS->read && !EC_GBL_OPTIONS->unoffensive && !EC_GBL_OPTIONS->only_mitm && EC_GBL_OPTIONS->ssl_mitm)
       ec_thread_new("sslwrap", "wrapper for ssl connections", &sslw_start, NULL);
 
-   GBL_SNIFF->active = 1;
+   EC_GBL_SNIFF->active = 1;
 }
 
 
@@ -81,15 +81,15 @@ void stop_unified_sniff(void)
    
    DEBUG_MSG("stop_unified_sniff");
    
-   if (GBL_SNIFF->active == 0) {
+   if (EC_GBL_SNIFF->active == 0) {
       USER_MSG("Unified sniffing is not running...\n");
       return;
    }
   
    /* kill it */
-   capture_stop(GBL_IFACE);
+   capture_stop(EC_GBL_IFACE);
 
-   if(GBL_OPTIONS->secondary)
+   if(EC_GBL_OPTIONS->secondary)
       secondary_sources_foreach(capture_stop);
    
    pid = ec_thread_getpid("sslwrap");
@@ -98,7 +98,7 @@ void stop_unified_sniff(void)
 
    USER_MSG("Unified sniffing was stopped.\n");
 
-   GBL_SNIFF->active = 0;
+   EC_GBL_SNIFF->active = 0;
 }
 
 
@@ -107,21 +107,21 @@ void forward_unified_sniff(struct packet_object *po)
    /* if it was not initialized, no packet are forwardable */
    switch(ntohs(po->L3.proto)) {
       case LL_TYPE_IP:
-         if(!GBL_LNET->lnet_IP4)
+         if(!EC_GBL_LNET->lnet_IP4)
             return;
-         if(!(GBL_IFACE->has_ipv4))
+         if(!(EC_GBL_IFACE->has_ipv4))
             return;
          break;
       case LL_TYPE_IP6:
-         if(!GBL_LNET->lnet_IP6)
+         if(!EC_GBL_LNET->lnet_IP6)
             return;
-         if(!(GBL_IFACE->has_ipv6))
+         if(!(EC_GBL_IFACE->has_ipv6))
             return;
          break;
    }
    
    /* if unoffensive is set, don't forward any packet */
-   if (GBL_OPTIONS->unoffensive || GBL_OPTIONS->read)
+   if (EC_GBL_OPTIONS->unoffensive || EC_GBL_OPTIONS->read)
       return;
 
    /* 
@@ -148,15 +148,15 @@ void forward_unified_sniff(struct packet_object *po)
 void unified_check_forwarded(struct packet_object *po) 
 {
    /* the interface was not configured, the packets are not forwardable */
-   if (!GBL_IFACE->is_ready)
+   if (!EC_GBL_IFACE->is_ready)
       return;
    
    /* 
     * dont sniff forwarded packets (equal mac, different ip) 
     * but only if we are on live connections
     */
-   if (GBL_CONF->skip_forwarded && !GBL_OPTIONS->read &&
-       !memcmp(GBL_IFACE->mac, po->L2.src, MEDIA_ADDR_LEN) &&
+   if (EC_GBL_CONF->skip_forwarded && !EC_GBL_OPTIONS->read &&
+       !memcmp(EC_GBL_IFACE->mac, po->L2.src, MEDIA_ADDR_LEN) &&
        ip_addr_is_ours(&po->L3.src) != E_FOUND) {
       po->flags |= PO_FORWARDED;
    }
@@ -164,8 +164,8 @@ void unified_check_forwarded(struct packet_object *po)
 
 /* 
  * if the dest mac address of the packet is
- * the same of GBL_IFACE->mac but the dest ip is
- * not the same as GBL_IFACE->ip, the packet is not
+ * the same of EC_GBL_IFACE->mac but the dest ip is
+ * not the same as EC_GBL_IFACE->ip, the packet is not
  * for us and we can do mitm on it before forwarding.
  */
 void unified_set_forwardable(struct packet_object *po)
@@ -174,8 +174,8 @@ void unified_set_forwardable(struct packet_object *po)
     * if the mac is our, but the ip is not...
     * it has to be forwarded
     */
-   if (!memcmp(GBL_IFACE->mac, po->L2.dst, MEDIA_ADDR_LEN) &&
-       memcmp(GBL_IFACE->mac, po->L2.src, MEDIA_ADDR_LEN) &&
+   if (!memcmp(EC_GBL_IFACE->mac, po->L2.dst, MEDIA_ADDR_LEN) &&
+       memcmp(EC_GBL_IFACE->mac, po->L2.src, MEDIA_ADDR_LEN) &&
        ip_addr_is_ours(&po->L3.dst) != E_FOUND) {
       po->flags |= PO_FORWARDABLE;
    }
