@@ -31,15 +31,16 @@
 #include <ec_socket.h>
 #include <ec_utils.h>
 #include <ec_sleep.h>
+#include <ec_redirect.h>
 
 #include <sys/types.h>
-#ifndef OS_WINDOWS
-   #include <sys/wait.h>
-#endif
 
 #ifdef OS_LINUX
    #include <linux/netfilter_ipv4.h>
 #endif
+#if defined OS_LINUX && defined WITH_IPV6
+   #include <linux/netfilter_ipv6/ip6_tables.h>
+#endif
 
 #include <fcntl.h>
 #include <pthread.h>
@@ -53,6 +54,10 @@
 #define OPENSSL_NO_KRB5 1
 #include <openssl/ssl.h>
 
+#if (OPENSSL_VERSION_NUMBER >= 0x10100000L)
+#define HAVE_OPAQUE_RSA_DSA_DH 1 /* since 1.1.0 -pre5 */
+#endif
+
 #define BREAK_ON_ERROR(x,y,z) do {  \
    if (x == -E_INVALID) {            \
       SAFE_FREE(z.DATA.disp_data);  \
@@ -74,6 +79,7 @@ static LIST_HEAD (, listen_entry) listen_ports;
 
 struct listen_entry {
    int fd;
+   int fd6;
    u_int16 sslw_port;   /* Port where we want to wrap SSL */
    u_int16 redir_port;  /* Port where accepts connections */
    u_char status;       /* Use directly SSL or not */
@@ -103,12 +109,8 @@ struct sslw_ident {
 };
 #define SSLW_IDENT_LEN sizeof(struct sslw_ident)
 
-#define SSLW_RETRY 5
-#define SSLW_WAIT 10 /* 10 seconds */
-
-#if defined(OS_DARWIN) || defined(OS_BSD)
-#define SSLW_SET "20"
-#endif
+#define SSLW_RETRY 500
+#define SSLW_WAIT 10 /* 10 milliseconds */
 
 
 #define TSLEEP (50*1000) /* 50 milliseconds */
@@ -134,8 +136,6 @@ static void sslw_create_session(struct ec_session **s, struct packet_object *po)
 static size_t sslw_create_ident(void **i, struct packet_object *po);            
 static void sslw_hook_handled(struct packet_object *po);
 static X509 *sslw_create_selfsigned(X509 *serv_cert);
-static int sslw_insert_redirect(u_int16 sport, u_int16 dport);
-static int sslw_remove_redirect(u_int16 sport, u_int16 dport);
 static void ssl_wrap_fini(void);
 static int sslw_ssl_connect(SSL *ssl_sk);
 static int sslw_ssl_accept(SSL *ssl_sk);
@@ -190,13 +190,13 @@ void ssl_wrap_init(void)
    struct listen_entry *le;
 
    /* disable if the aggressive flag is not set */
-   if (!GBL_CONF->aggressive_dissectors) {
+   if (!EC_GBL_CONF->aggressive_dissectors) {
       DEBUG_MSG("ssl_wrap_init: not aggressive");
       return;
    }
    
    /* a valid script for the redirection must be set */
-   if (!GBL_CONF->redir_command_on) {
+   if (!EC_GBL_CONF->redir_command_on) {
       DEBUG_MSG("ssl_wrap_init: no redirect script");
       USER_MSG("SSL dissection needs a valid 'redir_command_on' script in the etter.conf file\n");
       return;
@@ -212,6 +212,11 @@ void ssl_wrap_init(void)
    number_of_services = 0;
    LIST_FOREACH(le, &listen_ports, next) 
       number_of_services++;
+
+#ifdef WITH_IPV6
+   /* with IPv6 enabled we actually duplicate the number of listener sockets */
+   number_of_services *= 2;
+#endif
    
    SAFE_CALLOC(poll_fd, 1, sizeof(struct pollfd) * number_of_services);
 
@@ -224,9 +229,12 @@ static void ssl_wrap_fini(void)
    struct listen_entry *le, *old;
 
    DEBUG_MSG("ATEXIT: ssl_wrap_fini");
-   /* remove every redirect rule */   
+   /* remove every redirect rule and close listener sockets */
    LIST_FOREACH_SAFE(le, &listen_ports, next, old) {
-      sslw_remove_redirect(le->sslw_port, le->redir_port);
+      close(le->fd);
+#ifdef WITH_IPV6
+      close(le->fd6);
+#endif
       LIST_REMOVE(le, next);
       SAFE_FREE(le);
    }
@@ -234,6 +242,9 @@ static void ssl_wrap_fini(void)
    SSL_CTX_free(ssl_ctx_server);
    SSL_CTX_free(ssl_ctx_client);
 
+   /* remove redirects */
+   ec_redirect_cleanup();
+
 }
 
 /* 
@@ -243,8 +254,14 @@ EC_THREAD_FUNC(sslw_start)
 {
    struct listen_entry *le;
    struct accepted_entry *ae;
-   u_int len = sizeof(struct sockaddr_in), i;
-   struct sockaddr_in client_sin;
+   struct sockaddr_storage client_ss;
+   struct sockaddr *sa;
+   struct sockaddr_in *sa4;
+#ifdef WITH_IPV6
+   struct sockaddr_in6 *sa6;
+#endif
+   u_int len = sizeof(client_ss);
+   int fd = 0, nfds = 0, i = 0;
 
    /* variable not used */
    (void) EC_THREAD_PARAM;
@@ -252,57 +269,86 @@ EC_THREAD_FUNC(sslw_start)
    ec_thread_init();
 
    /* disabled if not aggressive */
-   if (!GBL_CONF->aggressive_dissectors)
+   if (!EC_GBL_CONF->aggressive_dissectors)
       return NULL;
-   
+
    /* a valid script for the redirection must be set */
-   if (!GBL_CONF->redir_command_on)
+   if (!EC_GBL_CONF->redir_command_on)
       return NULL;
-   
+
    DEBUG_MSG("sslw_start: initialized and ready");
-   
-   /* Set the polling on all registered ssl services */
-   i=0;
+
+   /* set the polling on all registered services */
    LIST_FOREACH(le, &listen_ports, next) {
-      poll_fd[i].fd = le->fd;
-      poll_fd[i++].events = POLLIN;
+      poll_fd[nfds].fd = le->fd;
+      poll_fd[nfds].events = POLLIN;
+#ifdef WITH_IPV6
+      nfds++;
+      poll_fd[nfds].fd = le->fd6;
+      poll_fd[nfds].events = POLLIN;
+#endif
+      nfds++;
    }
 
    LOOP {
-      poll(poll_fd, number_of_services, -1);
-      
-      /* Check which port received connection */
-      for(i=0; i<number_of_services; i++) 
-         if (poll_fd[i].revents & POLLIN) {
-	 
-            LIST_FOREACH(le, &listen_ports, next) 
-               if (poll_fd[i].fd == le->fd)
-                  break;
-	    
-            DEBUG_MSG("ssl_wrapper -- got a connection on port %d [%d]", le->redir_port, le->sslw_port);
-            SAFE_CALLOC(ae, 1, sizeof(struct accepted_entry));
-	    
-            ae->fd[SSL_CLIENT] = accept(poll_fd[i].fd, (struct sockaddr *)&client_sin, &len);
-            
-            /* Error checking */
-            if (ae->fd[SSL_CLIENT] == -1) {
-               SAFE_FREE(ae);
-               continue;
+      poll(poll_fd, nfds, -1);
+
+      /* Find out which file descriptor got active */
+      for (i=0; i<nfds; i++) {
+         if (!(poll_fd[i].revents & POLLIN))
+            continue;
+
+         /* determine listen entry */
+         LIST_FOREACH(le, &listen_ports, next) {
+            if (poll_fd[i].fd == le->fd) {
+               fd = le->fd;
+               break;
             }
-	    
-            /* Set the server original port for protocol dissection */
-            ae->port[SSL_SERVER] = htons(le->sslw_port);
-            
-            /* Check if we have to enter SSL status */
-            ae->status = le->status;
-	       
-            /* Set the peer (client) in the connection list entry */
-            ae->port[SSL_CLIENT] = client_sin.sin_port;
-            ip_addr_init(&(ae->ip[SSL_CLIENT]), AF_INET, (u_char *)&(client_sin.sin_addr.s_addr));
-	   
-            /* create a detached thread */ 
-            ec_thread_new_detached("sslw_child", "ssl child", &sslw_child, ae, 1);
+#ifdef WITH_IPV6
+            if (poll_fd[i].fd == le->fd6) {
+               fd = le->fd6;
+               break;
+            }
+#endif
          }
+
+         DEBUG_MSG("ssl_wrapper -- got a connection on port %d [%d]", le->redir_port, le->sslw_port);
+         SAFE_CALLOC(ae, 1, sizeof(struct accepted_entry));
+
+         ae->fd[SSL_CLIENT] = accept(fd, (struct sockaddr *)&client_ss, &len);
+         
+         /* Error checking */
+         if (ae->fd[SSL_CLIENT] == -1) {
+            SAFE_FREE(ae);
+            continue;
+         }
+
+         /* Set the server original port for protocol dissection */
+         ae->port[SSL_SERVER] = htons(le->sslw_port);
+         
+         /* Check if we have to enter SSL status */
+         ae->status = le->status;
+
+         /* Set the peer (client) in the connection list entry */
+         sa = (struct sockaddr *)&client_ss;
+         switch (sa->sa_family) {
+            case AF_INET:
+               sa4 = (struct sockaddr_in *)&client_ss;
+               ae->port[SSL_CLIENT] = sa4->sin_port;
+               ip_addr_init(&(ae->ip[SSL_CLIENT]), AF_INET, (u_char *)&(sa4->sin_addr.s_addr));
+               break;
+#ifdef WITH_IPV6
+            case AF_INET6:
+               sa6 = (struct sockaddr_in6 *)&client_ss;
+               ae->port[SSL_CLIENT] = sa6->sin6_port;
+               ip_addr_init(&(ae->ip[SSL_CLIENT]), AF_INET6, (u_char *)&(sa6->sin6_addr.s6_addr));
+               break;
+#endif
+         }
+
+         /* create a detached thread */
+         ec_thread_new_detached("sslw_child", "ssl child", &sslw_child, ae, 1);
+      }
    }
 
    return NULL;
@@ -342,130 +388,6 @@ static void sslw_hook_handled(struct packet_object *po)
       po->flags |= PO_IGNORE;
 }
 
-/*
- * execute the script to add the redirection
- */
-static int sslw_insert_redirect(u_int16 sport, u_int16 dport)
-{
-   char asc_sport[16];
-   char asc_dport[16];
-   int ret_val = 0;
-   char *command;
-   char *param[4];
- 
-   /* the script is not defined */
-   if (GBL_CONF->redir_command_on == NULL)
-   {
-      USER_MSG("SSLStrip: cannot setup the redirect, did you uncomment the redir_command_on command on your etter.conf file?\n");
-      return -E_FATAL;
-   }
-   snprintf(asc_sport, 16, "%u", sport);
-   snprintf(asc_dport, 16, "%u", dport);
-
-   /* make the substitutions in the script */
-   command = strdup(GBL_CONF->redir_command_on);
-   str_replace(&command, "%iface", GBL_OPTIONS->iface);
-   str_replace(&command, "%port", asc_sport);
-   str_replace(&command, "%rport", asc_dport);
-
-#if defined(OS_DARWIN) || defined(OS_BSD)
-   str_replace(&command, "%set", SSLW_SET);
-#endif
-   
-   DEBUG_MSG("sslw_insert_redirect: [%s]", command);
-   
-   /* construct the params array for execvp */
-   param[0] = "sh";
-   param[1] = "-c";
-   param[2] = command;
-   param[3] = NULL;
-               
-   /* execute the script */ 
-   switch (fork()) {
-      case 0:
-         regain_privs();
-         execvp(param[0], param);
-         drop_privs();
-         WARN_MSG("Cannot setup http redirect (command: %s), please edit your etter.conf file and put a valid value in redir_command_on field\n", param[0]);
-         SAFE_FREE(command);
-         _exit(-E_INVALID);
-      case -1:
-         SAFE_FREE(command);
-         return -E_INVALID;
-      default:
-         wait(&ret_val);
-         if (WIFEXITED(ret_val) && WEXITSTATUS(ret_val)) {
-            USER_MSG("sslwrap: redir_command_on had non-zero exit status (%d): [%s]\n", WEXITSTATUS(ret_val), command);
-            SAFE_FREE(command);
-            return -E_INVALID;
-         }
-   }    
-   
-   SAFE_FREE(command);
-   return E_SUCCESS;
-}
-
-/*
- * execute the script to remove the redirection
- */
-static int sslw_remove_redirect(u_int16 sport, u_int16 dport)
-{
-   char asc_sport[16];
-   char asc_dport[16];
-   int ret_val = 0;
-   char *command;
-   char *param[4];
- 
-   /* the script is not defined */
-   if (GBL_CONF->redir_command_off == NULL)
-   {
-      USER_MSG("SSLStrip: cannot remove the redirect, did you uncomment the redir_command_off command on your etter.conf file?");
-      return -E_FATAL;
-   }
-
-   snprintf(asc_sport, 16, "%u", sport);
-   snprintf(asc_dport, 16, "%u", dport);
-
-   /* make the substitutions in the script */
-   command = strdup(GBL_CONF->redir_command_off);
-   str_replace(&command, "%iface", GBL_OPTIONS->iface);
-   str_replace(&command, "%port", asc_sport);
-   str_replace(&command, "%rport", asc_dport);
-
-#if defined(OS_DARWIN) || defined(OS_BSD)
-   str_replace(&command, "%set", SSLW_SET);
-#endif
-   
-   DEBUG_MSG("sslw_remove_redirect: [%s]", command);
-   
-   /* construct the params array for execvp */
-   param[0] = "sh";
-   param[1] = "-c";
-   param[2] = command;
-   param[3] = NULL;
-
-   /* execute the script */ 
-   switch (fork()) {
-      case 0:
-         regain_privs();
-         execvp(param[0], param);
-         drop_privs();
-         WARN_MSG("Cannot remove http redirect (command: %s), please edit your etter.conf file and put a valid value in redir_command_on field\n", param[0]);
-         SAFE_FREE(command);
-         _exit(-E_INVALID);
-      case -1:
-         SAFE_FREE(command);
-         return -E_INVALID;
-      default:
-         wait(&ret_val);
-         SAFE_FREE(command);
-         if (ret_val == -E_INVALID)
-            return -E_INVALID;
-   }    
-   
-   return E_SUCCESS;
-}
-
 
 /* 
  * Check if this packet is for ssl wrappers 
@@ -497,16 +419,20 @@ static void sslw_bind_wrapper(void)
    u_int16 bind_port = EC_MAGIC_16; 
    struct listen_entry *le;
    struct sockaddr_in sa_in;
+#ifdef WITH_IPV6
+   struct sockaddr_in6 sa_in6;
+   int optval = 1;
+#endif
+
+   LIST_FOREACH(le, &listen_ports, next) {
 
-   LIST_FOREACH(le, &listen_ports, next) { 
-   
       le->fd = socket(AF_INET, SOCK_STREAM, 0);
       if (le->fd == -1)
         FATAL_ERROR("Unable to create socket in sslw_bind_wrapper()");
       memset(&sa_in, 0, sizeof(sa_in));
       sa_in.sin_family = AF_INET;
       sa_in.sin_addr.s_addr = INADDR_ANY;
-   
+
       do {
          bind_port++;
          sa_in.sin_port = htons(bind_port);
@@ -515,9 +441,48 @@ static void sslw_bind_wrapper(void)
 
       DEBUG_MSG("sslw - bind %d on %d", le->sslw_port, le->redir_port);
       if(listen(le->fd, 100) == -1)
-        FATAL_ERROR("Unable to accept connections for socket");      
-      if (sslw_insert_redirect(le->sslw_port, le->redir_port) != E_SUCCESS)
+        FATAL_ERROR("Unable to accept connections for socket");
+
+#ifdef WITH_IPV6
+      /* create & bind IPv6 socket on the same port */
+      le->fd6 = socket(AF_INET6, SOCK_STREAM, 0);
+      if (le->fd6 == -1)
+        FATAL_ERROR("Unable to create socket in sslw_bind_wrapper() for IPv6");
+      memset(&sa_in6, 0, sizeof(sa_in6));
+      sa_in6.sin6_family = AF_INET6;
+      sa_in6.sin6_addr = in6addr_any;
+      sa_in6.sin6_port = htons(bind_port);
+
+      /* we only listen on v6 as we use dedicated sockets per AF */
+      if (setsockopt(le->fd6, IPPROTO_IPV6, IPV6_V6ONLY,
+               &optval, sizeof(optval)) == -1) 
+         FATAL_ERROR("Unable to set IPv6 socket to IPv6 only in sslw_bind_wrapper(): %s", 
+               strerror(errno));
+
+      /* bind to IPv6 on the same port as the IPv4 socket */
+      if (bind(le->fd6, (struct sockaddr *)&sa_in6, sizeof(sa_in6)) == -1)
+         FATAL_ERROR("Unable to bind() IPv6 socket to port %d in sslw_bind_wrapper(): %s",
+               bind_port, strerror(errno));
+
+      if(listen(le->fd6, 100) == -1)
+        FATAL_ERROR("Unable to accept connections for IPv6 socket");
+#else
+      /* properly init fd even if unused - necessary for select call */
+      le->fd6 = 0;
+#endif
+
+      if (ec_redirect(EC_REDIR_ACTION_INSERT, le->name,
+               EC_REDIR_PROTO_IPV4, NULL, NULL,
+               le->sslw_port, le->redir_port) != E_SUCCESS)
         FATAL_ERROR("Can't insert firewall redirects");
+
+#ifdef WITH_IPV6
+      if (ec_redirect(EC_REDIR_ACTION_INSERT, le->name,
+               EC_REDIR_PROTO_IPV6, NULL, NULL,
+               le->sslw_port, le->redir_port) != E_SUCCESS)
+        FATAL_ERROR("Can't insert firewall redirects");
+#endif
+
    }
 }
 
@@ -546,7 +511,7 @@ static int sslw_sync_conn(struct accepted_entry *ae)
  */
 static int sslw_ssl_connect(SSL *ssl_sk)
 { 
-   int loops = (GBL_CONF->connect_timeout * 10e5) / TSLEEP;
+   int loops = (EC_GBL_CONF->connect_timeout * 10e5) / TSLEEP;
    int ret, ssl_err;
 
    do {
@@ -574,7 +539,7 @@ static int sslw_ssl_connect(SSL *ssl_sk)
  */
 static int sslw_ssl_accept(SSL *ssl_sk)
 { 
-   int loops = (GBL_CONF->connect_timeout * 10e5) / TSLEEP;
+   int loops = (EC_GBL_CONF->connect_timeout * 10e5) / TSLEEP;
    int ret, ssl_err;
 
    do {
@@ -622,7 +587,7 @@ static int sslw_sync_ssl(struct accepted_entry *ae)
       return -E_INVALID;
    }
 
-   if (!GBL_OPTIONS->ssl_cert) {
+   if (!EC_GBL_OPTIONS->ssl_cert) {
    	/* Create the fake certificate */
    	ae->cert = sslw_create_selfsigned(server_cert);  
    	X509_free(server_cert);
@@ -670,7 +635,7 @@ static int sslw_get_peer(struct accepted_entry *ae)
     * which creates the session, may be slower than this
     */
    for (i=0; i<SSLW_RETRY && session_get_and_del(&s, ident, SSLW_IDENT_LEN)!=E_SUCCESS; i++)
-      ec_usleep(SEC2MICRO(SSLW_WAIT));
+      ec_usleep(MILLI2MICRO(SSLW_WAIT));
 
    if (i==SSLW_RETRY) {
       SAFE_FREE(ident);
@@ -684,12 +649,34 @@ static int sslw_get_peer(struct accepted_entry *ae)
    SAFE_FREE(s);
    SAFE_FREE(ident);
 #else
-   struct sockaddr_in sa_in;
-   socklen_t sa_in_sz = sizeof(struct sockaddr_in);
+   struct sockaddr_storage ss;
+   struct sockaddr_in *sa4;
+#if defined WITH_IPV6 && defined HAVE_IP6T_SO_ORIGINAL_DST
+   struct sockaddr_in6 *sa6;
+#endif
+   socklen_t ss_len = sizeof(struct sockaddr_storage);
 
-   getsockopt(ae->fd[SSL_CLIENT], SOL_IP, SO_ORIGINAL_DST, (struct sockaddr*)&sa_in, &sa_in_sz);
+   switch (ntohs(ae->ip[SSL_CLIENT].addr_type)) {
+      case AF_INET:
+         if (getsockopt(ae->fd[SSL_CLIENT], SOL_IP, SO_ORIGINAL_DST, (struct sockaddr*)&ss, &ss_len) == -1) {
+            WARN_MSG("getsockopt failed: %s", strerror(errno));
+            return -E_INVALID;
+         }
+         sa4 = (struct sockaddr_in *)&ss;
+         ip_addr_init(&(ae->ip[SSL_SERVER]), AF_INET, (u_char *)&(sa4->sin_addr.s_addr));
+         break;
+#if defined WITH_IPV6 && defined HAVE_IP6T_SO_ORIGINAL_DST
+      case AF_INET6:
+         if (getsockopt(ae->fd[SSL_CLIENT], IPPROTO_IPV6, IP6T_SO_ORIGINAL_DST, (struct sockaddr*)&ss, &ss_len) == -1) {
+            WARN_MSG("getsockopt failed: %s", strerror(errno));
+            return -E_INVALID;
+         }
+         sa6 = (struct sockaddr_in6 *)&ss;
+         ip_addr_init(&(ae->ip[SSL_SERVER]), AF_INET6, (u_char *)&(sa6->sin6_addr.s6_addr));
+         break;
+#endif
+   }
 
-   ip_addr_init(&(ae->ip[SSL_SERVER]), AF_INET, (u_char *)&(sa_in.sin_addr.s_addr));
 #endif
    return E_SUCCESS;
 }
@@ -702,23 +689,16 @@ static int sslw_get_peer(struct accepted_entry *ae)
  */
 static int sslw_connect_server(struct accepted_entry *ae)
 {
-   char *dest_ip;
+   char dest_ip[MAX_ASCII_ADDR_LEN];
    
-   /* 
-    * XXX - int_ntoa is not thread-safe. 
-    * strdup it to avoid race conditions.
-    * Btw int_ntoa is not so used in the code.
-    */
-   dest_ip = strdup(int_ntoa(*ae->ip[SSL_SERVER].addr32));
+   ip_addr_ntoa(&ae->ip[SSL_SERVER], dest_ip);
  
    /* Standard connection to the server */
-   if (!dest_ip || (ae->fd[SSL_SERVER] = open_socket(dest_ip, ntohs(ae->port[SSL_SERVER]))) < 0) {
-      SAFE_FREE(dest_ip);   
+   if ((ae->fd[SSL_SERVER] = open_socket(dest_ip, ntohs(ae->port[SSL_SERVER]))) < 0) {
       DEBUG_MSG("Could not open socket");
       return -E_INVALID;
    }
    
-   SAFE_FREE(dest_ip);	       
    return E_SUCCESS;   
 }
 
@@ -856,7 +836,7 @@ static void sslw_parse_packet(struct accepted_entry *ae, u_int32 direction, stru
     * ssl childs keep the connection alive even if the sniffing thread
     * was stopped. But don't add packets to top-half queue.
     */
-   if (!GBL_SNIFF->active)
+   if (!EC_GBL_SNIFF->active)
       return;
 
    memcpy(&po->L3.src, &ae->ip[direction], sizeof(struct ip_addr));
@@ -873,7 +853,7 @@ static void sslw_parse_packet(struct accepted_entry *ae, u_int32 direction, stru
    /* calculate if the dest is local or not */
    switch (ip_addr_is_local(&PACKET->L3.src, NULL)) {
       case E_SUCCESS:
-         PACKET->PASSIVE.flags &= ~FP_HOST_NONLOCAL;
+         PACKET->PASSIVE.flags &= ~(FP_HOST_NONLOCAL);
          PACKET->PASSIVE.flags |= FP_HOST_LOCAL;
          break;
       case -E_NOTFOUND:
@@ -958,25 +938,35 @@ static X509 *sslw_create_selfsigned(X509 *server_cert)
    
    if ((out_cert = X509_new()) == NULL)
       return NULL;
-      
+
    /* Set out public key, real server name... */
    X509_set_version(out_cert, X509_get_version(server_cert));
-   X509_set_serialNumber(out_cert, X509_get_serialNumber(server_cert));   
+   ASN1_INTEGER_set(X509_get_serialNumber(out_cert), EC_MAGIC_32);
    X509_set_notBefore(out_cert, X509_get_notBefore(server_cert));
    X509_set_notAfter(out_cert, X509_get_notAfter(server_cert));
    X509_set_pubkey(out_cert, global_pk);
    X509_set_subject_name(out_cert, X509_get_subject_name(server_cert));
    X509_set_issuer_name(out_cert, X509_get_issuer_name(server_cert));  
-   
+
    /* Modify the issuer a little bit */ 
    //X509_NAME_add_entry_by_txt(X509_get_issuer_name(out_cert), "L", MBSTRING_ASC, " ", -1, -1, 0);
 
    index = X509_get_ext_by_NID(server_cert, NID_authority_key_identifier, -1);
    if (index >=0) {
       ext = X509_get_ext(server_cert, index);
+#ifdef HAVE_OPAQUE_RSA_DSA_DH
+      ASN1_OCTET_STRING* os;
+      os = X509_EXTENSION_get_data (ext);
+#endif
       if (ext) {
+#ifdef HAVE_OPAQUE_RSA_DSA_DH
+         os->data[7] = 0xe7;
+         os->data[8] = 0x7e;
+         X509_EXTENSION_set_data (ext, os);
+#else
          ext->value->data[7] = 0xe7;
          ext->value->data[8] = 0x7e;
+#endif
          X509_add_ext(out_cert, ext, -1);
       }
    }
@@ -1008,25 +998,25 @@ static void sslw_init(void)
    ON_ERROR(ssl_ctx_client, NULL, "Could not create client SSL CTX");
    ON_ERROR(ssl_ctx_server, NULL, "Could not create server SSL CTX");
 
-   if(GBL_OPTIONS->ssl_pkey) {
+   if(EC_GBL_OPTIONS->ssl_pkey) {
 	/* Get our private key from the file specified from cmd-line */
-	DEBUG_MSG("Using custom private key %s", GBL_OPTIONS->ssl_pkey);
-	if (SSL_CTX_use_PrivateKey_file(ssl_ctx_client, GBL_OPTIONS->ssl_pkey, SSL_FILETYPE_PEM) == 0) {
-		FATAL_ERROR("Can't open \"%s\" file : %s", GBL_OPTIONS->ssl_pkey, strerror(errno));
+	DEBUG_MSG("Using custom private key %s", EC_GBL_OPTIONS->ssl_pkey);
+	if (SSL_CTX_use_PrivateKey_file(ssl_ctx_client, EC_GBL_OPTIONS->ssl_pkey, SSL_FILETYPE_PEM) == 0) {
+		FATAL_ERROR("Can't open \"%s\" file : %s", EC_GBL_OPTIONS->ssl_pkey, strerror(errno));
 	}
 
-	if (GBL_OPTIONS->ssl_cert) {
-		if (SSL_CTX_use_certificate_file(ssl_ctx_client, GBL_OPTIONS->ssl_cert, SSL_FILETYPE_PEM) == 0) {
-			FATAL_ERROR("Can't open \"%s\" file : %s", GBL_OPTIONS->ssl_cert, strerror(errno));
+	if (EC_GBL_OPTIONS->ssl_cert) {
+		if (SSL_CTX_use_certificate_file(ssl_ctx_client, EC_GBL_OPTIONS->ssl_cert, SSL_FILETYPE_PEM) == 0) {
+			FATAL_ERROR("Can't open \"%s\" file : %s", EC_GBL_OPTIONS->ssl_cert, strerror(errno));
 		}
 
 		if (!SSL_CTX_check_private_key(ssl_ctx_client)) {
-			FATAL_ERROR("Certificate \"%s\" does not match private key \"%s\"", GBL_OPTIONS->ssl_cert, GBL_OPTIONS->ssl_pkey);
+			FATAL_ERROR("Certificate \"%s\" does not match private key \"%s\"", EC_GBL_OPTIONS->ssl_cert, EC_GBL_OPTIONS->ssl_pkey);
 		}
 	}
    } else {
    	/* Get our private key from our cert file */
-   	if (SSL_CTX_use_PrivateKey_file(ssl_ctx_client, INSTALL_DATADIR "/" EC_PROGRAM "/" CERT_FILE, SSL_FILETYPE_PEM) == 0) {
+   	if (SSL_CTX_use_PrivateKey_file(ssl_ctx_client, INSTALL_DATADIR "/" PROGRAM "/" CERT_FILE, SSL_FILETYPE_PEM) == 0) {
       		DEBUG_MSG("sslw -- SSL_CTX_use_PrivateKey_file -- trying ./share/%s",  CERT_FILE);
 
       		if (SSL_CTX_use_PrivateKey_file(ssl_ctx_client, "./share/" CERT_FILE, SSL_FILETYPE_PEM) == 0)
