@@ -64,25 +64,27 @@ void toggle_resolve(void)
    struct hosts_list *hl;
 
    /* resolution already set */
-   if (GBL_OPTIONS->resolve) {
-      GBL_OPTIONS->resolve = 0;
+   if (EC_GBL_OPTIONS->resolve) {
+      EC_GBL_OPTIONS->resolve = 0;
+      resolv_thread_fini();
       return;
    } 
 
    DEBUG_MSG("toggle_resolve: activate name resolution");
 
-   /* set the option */
-   GBL_OPTIONS->resolve = 1;
+   /* set the option and activate resolution threads */
+   EC_GBL_OPTIONS->resolve = 1;
+   resolv_thread_init();
 
    /* run through the current hosts list and trigger resolution */
-   LIST_FOREACH(hl, &GBL_HOSTLIST, next) {
+   LIST_FOREACH(hl, &EC_GBL_HOSTLIST, next) {
       if (hl->hostname)
          continue;
       host_iptoa(&hl->ip, name);
    }
 
    /* actually refresh the host list */
-   GBL_UI->update(UI_UPDATE_HOSTLIST);
+   EC_GBL_UI->update(UI_UPDATE_HOSTLIST);
 }
 
 /*
@@ -274,37 +276,37 @@ static gboolean refresh_stats(gpointer data)
    if (!gtk_widget_get_visible(stats_window))
       return FALSE;
 
-   snprintf(line, 50, "%8"PRIu64, GBL_STATS->ps_recv);
+   snprintf(line, 50, "%8"PRIu64, EC_GBL_STATS->ps_recv);
    gtk_label_set_text(GTK_LABEL (packets_recv), line);
-   snprintf(line, 50, "%8"PRIu64"  %.2f %%", GBL_STATS->ps_drop, 
-         (GBL_STATS->ps_recv) ? (float)GBL_STATS->ps_drop * 100 / GBL_STATS->ps_recv : 0 );
+   snprintf(line, 50, "%8"PRIu64"  %.2f %%", EC_GBL_STATS->ps_drop, 
+         (EC_GBL_STATS->ps_recv) ? (float)EC_GBL_STATS->ps_drop * 100 / EC_GBL_STATS->ps_recv : 0 );
    gtk_label_set_text(GTK_LABEL (packets_drop), line);
-   snprintf(line, 50, "%8"PRIu64"  bytes: %8"PRIu64" ", GBL_STATS->ps_sent, GBL_STATS->bs_sent);
+   snprintf(line, 50, "%8"PRIu64"  bytes: %8"PRIu64" ", EC_GBL_STATS->ps_sent, EC_GBL_STATS->bs_sent);
    gtk_label_set_text(GTK_LABEL (packets_forw), line);
-   snprintf(line, 50, "%lu/%lu ", GBL_STATS->queue_curr, GBL_STATS->queue_max);
+   snprintf(line, 50, "%lu/%lu ", EC_GBL_STATS->queue_curr, EC_GBL_STATS->queue_max);
    gtk_label_set_text(GTK_LABEL (queue_len), line);
-   snprintf(line, 50, "%d ", GBL_CONF->sampling_rate);
+   snprintf(line, 50, "%d ", EC_GBL_CONF->sampling_rate);
    gtk_label_set_text(GTK_LABEL (sample_rate), line);
    snprintf(line, 50, "pck: %8"PRIu64"  bytes: %8"PRIu64, 
-         GBL_STATS->bh.pck_recv, GBL_STATS->bh.pck_size);
+         EC_GBL_STATS->bh.pck_recv, EC_GBL_STATS->bh.pck_size);
    gtk_label_set_text(GTK_LABEL (recv_bottom), line);
    snprintf(line, 50, "pck: %8"PRIu64"  bytes: %8"PRIu64, 
-         GBL_STATS->th.pck_recv, GBL_STATS->th.pck_size);
+         EC_GBL_STATS->th.pck_recv, EC_GBL_STATS->th.pck_size);
    gtk_label_set_text(GTK_LABEL (recv_top), line);
    snprintf(line, 50, "%.2f %%",
-         (GBL_STATS->bh.pck_recv) ? (float)GBL_STATS->th.pck_recv * 100 / GBL_STATS->bh.pck_recv : 0 );
+         (EC_GBL_STATS->bh.pck_recv) ? (float)EC_GBL_STATS->th.pck_recv * 100 / EC_GBL_STATS->bh.pck_recv : 0 );
    gtk_label_set_text(GTK_LABEL (interesting), line);
    snprintf(line, 50, "worst: %8lu  adv: %8lu p/s", 
-         GBL_STATS->bh.rate_worst, GBL_STATS->bh.rate_adv);
+         EC_GBL_STATS->bh.rate_worst, EC_GBL_STATS->bh.rate_adv);
    gtk_label_set_text(GTK_LABEL (rate_bottom), line);
    snprintf(line, 50, "worst: %8lu  adv: %8lu p/s", 
-         GBL_STATS->th.rate_worst, GBL_STATS->th.rate_adv);
+         EC_GBL_STATS->th.rate_worst, EC_GBL_STATS->th.rate_adv);
    gtk_label_set_text(GTK_LABEL (rate_top), line);
    snprintf(line, 50, "worst: %8lu  adv: %8lu b/s", 
-         GBL_STATS->bh.thru_worst, GBL_STATS->bh.thru_adv);
+         EC_GBL_STATS->bh.thru_worst, EC_GBL_STATS->bh.thru_adv);
    gtk_label_set_text(GTK_LABEL (through_bottom), line);
    snprintf(line, 50, "worst: %8lu  adv: %8lu b/s", 
-         GBL_STATS->th.thru_worst, GBL_STATS->th.thru_adv);
+         EC_GBL_STATS->th.thru_worst, EC_GBL_STATS->th.thru_adv);
    gtk_label_set_text(GTK_LABEL (through_top), line);
 
    return(TRUE);
