@@ -195,6 +195,13 @@ enum {
    HOOK_PACKET_ICMP6,
    HOOK_PACKET_ICMP6_NSOL,
    HOOK_PACKET_ICMP6_NADV,
+   HOOK_PACKET_ICMP6_RPLY,
+   HOOK_PACKET_ICMP6_PARM,
+   HOOK_PACKET_PPPOE,
+   HOOK_PACKET_PPP_PAP,
+   HOOK_PACKET_MPLS,
+   HOOK_PACKET_ERF,
+   HOOK_PACKET_ESP,
 
    /* high level protocol hooks */
    HOOK_PROTO_BASE   = 100,
@@ -205,6 +212,7 @@ enum {
    HOOK_PROTO_DHCP_DISCOVER,
    HOOK_PROTO_DHCP_PROFILE,
    HOOK_PROTO_DNS,
+   HOOK_PROTO_MDNS,
    HOOK_PROTO_NBNS,
    HOOK_PROTO_HTTP,
 };
