@@ -4,21 +4,20 @@
  * 
  */
 
-#include <stdio.h>
-#include <string.h>
-
-char *strcasestr(char *hailstack, char *needle);
+#include <ec.h>
 
+char *strcasestr(const char *hailstack, const char *needle);
    
-char *strcasestr(char *hailstack, char *needle)
+char *strcasestr(const char *hailstack, const char *needle)
 {
    register int lneed = strlen(needle);
    register int lhail = strlen(hailstack);
    register int i;
 
-   for (i = 0; i < lhail; i++) 
+   for (i = 0; i < lhail; i++) {
       if (!strncasecmp(hailstack + i, needle, lneed))
          return hailstack + i;
+   }
 
    return NULL;
 }
