@@ -53,9 +53,9 @@ FUNC_DECODER(decode_icmp6)
    DECODED_LEN = sizeof(struct icmp6_hdr);
 
    /* this sucked. Now it sucks less. */ 
-   if(GBL_CONF->checksum_check && !GBL_OPTIONS->unoffensive) {
+   if(EC_GBL_CONF->checksum_check && !EC_GBL_OPTIONS->unoffensive) {
       if((csum = L4_checksum(PACKET)) != CSUM_RESULT) {
-         if(GBL_CONF->checksum_warning) {
+         if(EC_GBL_CONF->checksum_warning) {
             char tmp[MAX_ASCII_ADDR_LEN];
             USER_MSG("Invalid ICMPv6 packet from %s : csum [%#x] should be (%#x)\n",
                      ip_addr_ntoa(&PACKET->L3.src, tmp), ntohs(icmp6->csum),
